==> transfer_nlp-0.1.4.tar.gz: transfer_nlp-0.1.4/setup.py <==
from setuptools import setup, find_packages
from io import open

setup(
    name='transfer_nlp',
    packages=find_packages(exclude=["*.tests", "*.tests.*",
                                    "tests.*", "tests"]),
    version='0.1.4',
    license='MIT',
    description='NLP library designed for flexible research and development',
    long_description=open("README.md", "r", encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author='Peter Martigny',
    author_email='peter.martigny@gmail.com',
    url='https://github.com/feedly/transfer-nlp',
    download_url='https://github.com/feedly/transfer-nlp/archive/v0.1.4.tar.gz',
    keywords=['NLP', 'transfer learning', 'language models', 'NLU'],
    install_requires=[
        'tqdm>=4.31.1',
        'matplotlib>=3.0.3',
        'nltk>=3.4',
        'pandas>=0.24.1',
        'seaborn>=0.9.0',
        'scipy>=1.2.1',
        'annoy>=1.15.0',
        'numpy>=1.16.2',
        'requests>=2.21.0',
        'torch==1.0.1.post2',
        'ipython==6.2.1',
        'feedly-client>=0.20',
        'bs4>=0.0.1',
        'tensorboardX==1.6',
        'knockknock>=0.1',
        'pytorch-ignite>==0.2.0',
        'smart_open>=1.8.1'
    ],
    setup_requires=['green'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
    ],
)

==> transfer_nlp-0.1.5.tar.gz: transfer_nlp-0.1.5/setup.py <==
from setuptools import setup, find_packages
from io import open

setup(
    name='transfer_nlp',
    packages=find_packages(exclude=["*.tests", "*.tests.*",
                                    "tests.*", "tests"]),
    version='0.1.5',
    license='MIT',
    description='NLP library designed for flexible research and development',
    long_description=open("README.md", "r", encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author='Peter Martigny',
    author_email='peter.martigny@gmail.com',
    url='https://github.com/feedly/transfer-nlp',
    download_url='https://github.com/feedly/transfer-nlp/archive/v0.1.5.tar.gz',
    keywords=['NLP', 'transfer learning', 'language models', 'NLU'],
    install_requires=[
        'tqdm>=4.31.1',
        'matplotlib>=3.0.3',
        'nltk>=3.4',
        'pandas>=0.24.1',
        'seaborn>=0.9.0',
        'scipy>=1.2.1',
        'annoy>=1.15.0',
        'numpy>=1.16.2',
        'requests>=2.21.0',
        'torch>=1.1.0',
        'ipython==6.2.1',
        'feedly-client>=0.20',
        'bs4>=0.0.1',
        'tensorboardX==1.6',
        'knockknock>=0.1',
        'pytorch-ignite>=0.2.0',
        'smart_open>=1.8.1',
        'pytorch_pretrained_bert>=0.6.1'
    ],
    setup_requires=['green'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
    ],
)
